;;; hankana.el --- hankaku katakana utils

;; Copyright (C) 2002 Masanao Izumo

;; Maintainer: Masanao Izumo <iz@onicos.co.jp>
;; Version: 1.0.0

;; This library is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with library; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

(defvar zenkana-hankana-map
  '(("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "Î") ("" . "Ď")
    ("" . "ʎ") ("" . "ˎ") ("" . "̎") ("" . "͎") ("" . "Ύ")
    ("" . "ʎ") ("" . "ˎ") ("" . "̎") ("" . "͎") ("" . "Ύ")

    ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "")
    ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "")
    ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "") ("" . "") ("" . "") ("" . "")
    ("" . "") ("" . "")
    ))

(defvar hankana-zenkana-map
  (mapcar #'(lambda (pair) (cons (cdr pair) (car pair)))
	  zenkana-hankana-map))

(defun hankana-convert-region (start end map-alist)
  (save-excursion
    (save-restriction
      (narrow-to-region (point-min) end)
      (goto-char start)
      (while (not (eobp))
	(let ((found nil)
	      (map map-alist))
	  (while (and map (not found))
	    (if (looking-at (car (car map)))
		(setq found (car map))
	      (setq map (cdr map))))
	  (if found
	      (progn
		(delete-region (match-beginning 0) (match-end 0))
		(insert (cdr found)))
	    (forward-char 1)))))))

(defun hankana-zenkana-region (start end)
  (interactive "r")
  (hankana-convert-region start end hankana-zenkana-map))

(defun zenkana-hankana-region (start end)
  (interactive "r")
  (hankana-convert-region start end zenkana-hankana-map))

(provide 'hankana)
